translate.storage.omegat

Package translate :: Package storage :: Module omegat |
[hide private]
[frames] | no frames]

# Module omegat

source code

Manage the OmegaT glossary format

OmegaT glossary format is used by the OmegaT computer aided translation tool.

It is a bilingual base class derived format with OmegaTFile and OmegaTUnit providing file and unit level access.

# Format Implementation

The OmegaT glossary format is a simple Tab Separated Value (TSV) file with the columns: source, target, comment.

The dialect of the TSV files is specified by OmegaTDialect.

## Encoding

The files are either UTF-8 or encoded using the system default. UTF-8 encoded files use the .utf8 extension while system encoded files use the .tab extension.

Classes | [hide private]
| OmegaTDialect Describe the properties of an OmegaT generated TAB-delimited file.
| OmegaTUnit An OmegaT translation memory unit
| OmegaTFile An OmegaT translation memory file
| OmegaTFileTab An OmegT translation memory file in the default system encoding

Variables | [hide private]
| OMEGAT_FIELDNAMES = `["source", "target", "comment"]` Field names for an OmegaT glossary unit

Imports: csv, locale, os, sys, time, base